==============
latticeadaptor
==============



This package is used to convert a table of accelerator lattice elements and their arguments 
to various accelerator lattice formats. Currently covered are:

- MadX (Sequence and Line format)
- Elegant
- Tracy

* Free software: MIT license
* Documentation: https://latticeadaptor.readthedocs.io.


Features
--------

* Fast lattice comparison by plotting element locations against eachother.
* Fast settings compare by comparing magnet settings.
* Quick twiss plotting.
* Quick lattice element plotting.
* Conversion from table to standard formats.
